from typing import *

# usage.matplotlib: 6
# usage.scipy: 30
# usage.skimage: 10
# usage.sklearn: 6
assert_allclose: object

# usage.scipy: 15
# usage.skimage: 3
# usage.sklearn: 3
assert_almost_equal: object

# usage.sklearn: 1
assert_approx_equal: object

# usage.scipy: 1
assert_equal: object
